import os

import errno


def mkdir_p(path):
    """
    Creates directory unless it already exists

    :param str path: Path of directory to make
    """
    try:
        os.makedirs(path)
    except OSError as exc:
        if exc.errno == errno.EEXIST and os.path.isdir(path):
            pass
        else:
            raise

def flatten(x):
    """
    Flattens a nested array into a single list

    :param list x: The nested list/tuple to be flattened
    """
    result = []
    for el in x:
        if hasattr(el, "__iter__") and not isinstance(el, basestring):
            result.extend(flatten(el))
        else:
            result.append(el)
    return result


def merge_dicts(x, y):
    """
    Given two dicts, merge them into a new dict as a shallow copy

    param dict x: first dictionary
    param dict y: second dictionary
    """
    z = x.copy()
    z.update(y)
    return z



import os
import pickle

__location__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(__file__)))


def return_samples():
    """
    Returns sample dictionary which maps TCGA and GTEx samples to a tissue.
    Synapse ID: syn10296681

    :return: Tissues are keys are list of samples are values
    :rtype: dict[list]
    """
    return pickle.load(os.path.join(__location__, 'samples.pickle'))



from setuptools import setup, find_packages

setup(name='rnaseq-lib',
      version='1.0a5',
      description='',
      url='http://github.com/jvivian/rnaseq-lib',
      author='John Vivian',
      author_email='jtvivian@gmail.com',
      license='MIT',
      package_dir={'': 'src'},
      packages=find_packages('src'),
      install_requires=['pandas',
                        'numpy',
                        'seaborn'])